==> payroll_ver_3.2.0.zip: payroll3/src/jp/mosp/payroll/common/PayrollMenuConst.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.payroll.common;

import jp.mosp.common.MosPMenuConst;

public class PayrollMenuConst extends MosPMenuConst {

	/*ΑӏWv֘A*/
	private static final String[] MENU_PAYROLL		= { "P1001", "^vZ"			};
	private static final String[] MENU_PAYROLL_MASTER	= { "P1002", "^vZ}X^"	};
	private static final String[] MENU_PAYROLL_EXP   = { "P9003", "^GNX|[g"	};
	private static final String[] MENU_KINTAI_EXP   = { "S1200", "ΑӃGNX|[g"	};

	// ܗ^ǉ
	private static final String[] MENU_CALC_BONUS	= { "P2001", "ܗ^vZ" };

	// ^ǉ
	private static final String[] MENU_REFER_SLIP = { "P8500", "ܗ^"};
	
	// Nǉ
	private static final String[] MENU_ADJUSTMENT = { "P3000", "N"};

	// Љیǉ
//	private static final String[] MENU_INSURANCE = { "P4000", "Љی"};	//Еۃj[L
	private static final String[] MENU_INSURANCE = { "P4001", "Љی"};      //Еۃj[

	/*\֘A*/
	private static final String[] MENU_APPLICATION 			= { "K1400", "e\"		};
	
	/*^pR}h̔z*/
	private static final String[][] CMD_PAYROLL_ARRAY = {
		MENU_ATTENDANCE_CALCULATE(),
		MENU_ATTENDANCE_CALCULATE_START(),
		MENU_ATTENDANCE_COMPILE(),
		MENU_COMPILE_AMENDMENT(),
		MENU_ATTENDANCE_EXPORT(),
		MENU_ATTENDANCE_CALCULATE_END(),
		MENU_YUKYU_MANAGEMENT(),
		MENU_KEISAN_INFORMATION(),		
		//MENU_EXPORT(),
		MENU_KINTAI_EXP,
		MENU_PAYROLL,
		MENU_CALC_BONUS,	/* ܗ^vZ */
		MENU_PAYROLL_EXP,
		MENU_ADJUSTMENT,    /* N */
		MENU_INSURANCE,     /* Љی */
		MENU_PAYROLL_MASTER
	};

	/*]ƈpR}h̔z*/
	private static final String[][] CMD_EMPLOYEE_ARRAY = {
		MENU_ATTENDANCE(),
		MENU_SCHEDULE(),
		MENU_PAID_HOLIDAY(),		
		MENU_APPLICATION,
	//	MENU_MOSP_PASSWORD(),
		MENU_REFER_SLIP
	};

	/**
	 * ^pR}h̔z
	 * @return array
	 */
	public static String[][] getPayrollCmdArray() {
		return CMD_PAYROLL_ARRAY.clone();
	}

	/**
	 * ]ƈpR}h̔z
	 * @return array
	 */
	public static String[][] getEmployeeCmdArray() {
		return CMD_EMPLOYEE_ARRAY.clone();
	}
	
}

==> payroll_ver_3.2.1.zip: payroll3/src/jp/mosp/payroll/common/PayrollMenuConst.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.payroll.common;

import jp.mosp.common.MosPMenuConst;

public class PayrollMenuConst extends MosPMenuConst {

	/*ΑӏWv֘A*/
	private static final String[] MENU_PAYROLL		= { "P1001", "^vZ"			};
	private static final String[] MENU_PAYROLL_MASTER	= { "P1002", "^vZ}X^"	};
	private static final String[] MENU_PAYROLL_EXP   = { "P9003", "^GNX|[g"	};
	private static final String[] MENU_KINTAI_EXP   = { "S1200", "ΑӃGNX|[g"	};

	// ܗ^ǉ
	private static final String[] MENU_CALC_BONUS	= { "P2001", "ܗ^vZ" };

	// ^ǉ
	private static final String[] MENU_REFER_SLIP = { "P8500", "ܗ^"};
	
	// Nǉ
	private static final String[] MENU_ADJUSTMENT = { "P3000", "N"};

	// Љیǉ
//	private static final String[] MENU_INSURANCE = { "P4000", "Љی"};	//Еۃj[L
	private static final String[] MENU_INSURANCE = { "P4001", "Љی"};      //Еۃj[

	/*\֘A*/
	private static final String[] MENU_APPLICATION 			= { "K1400", "e\"		};
	
	/*^pR}h̔z*/
	private static final String[][] CMD_PAYROLL_ARRAY = {
		MENU_ATTENDANCE_CALCULATE(),
		MENU_ATTENDANCE_CALCULATE_START(),
		MENU_ATTENDANCE_COMPILE(),
		MENU_COMPILE_AMENDMENT(),
		MENU_ATTENDANCE_EXPORT(),
		MENU_ATTENDANCE_CALCULATE_END(),
		MENU_YUKYU_MANAGEMENT(),
		MENU_KEISAN_INFORMATION(),		
		//MENU_EXPORT(),
		MENU_KINTAI_EXP,
		MENU_PAYROLL,
		MENU_CALC_BONUS,	/* ܗ^vZ */
		MENU_PAYROLL_EXP,
		MENU_ADJUSTMENT,    /* N */
		MENU_INSURANCE,     /* Љی */
		MENU_PAYROLL_MASTER
	};

	/*]ƈpR}h̔z*/
	private static final String[][] CMD_EMPLOYEE_ARRAY = {
		MENU_ATTENDANCE(),
		MENU_SCHEDULE(),
		MENU_PAID_HOLIDAY(),		
		MENU_APPLICATION,
		MENU_MOSP_PASSWORD(),
		MENU_REFER_SLIP
	};

	/**
	 * ^pR}h̔z
	 * @return array
	 */
	public static String[][] getPayrollCmdArray() {
		return CMD_PAYROLL_ARRAY.clone();
	}

	/**
	 * ]ƈpR}h̔z
	 * @return array
	 */
	public static String[][] getEmployeeCmdArray() {
		return CMD_EMPLOYEE_ARRAY.clone();
	}
	
}
